==> novaideo-1.0.tar.gz: novaideo-1.0/novaideo/content/processes/comment_management/definition.py <==
# Copyright (c) 2014 by Ecreall under licence AGPL terms
# avalaible on http://www.gnu.org/licenses/agpl.html

# licence: AGPL
# author: Amen Souissi
"""
This module represent the Comment management process definition
powered by the dace engine. This process is unique, which means that
this process is instantiated only once.
"""
from dace.processdefinition.processdef import ProcessDefinition
from dace.processdefinition.activitydef import ActivityDefinition
from dace.processdefinition.gatewaydef import (
    ExclusiveGatewayDefinition,
    ParallelGatewayDefinition)
from dace.processdefinition.transitiondef import TransitionDefinition
from dace.processdefinition.eventdef import (
    StartEventDefinition,
    EndEventDefinition)
from dace.objectofcollaboration.services.processdef_container import (
    process_definition)
from pontus.core import VisualisableElement

from .behaviors import Respond
from novaideo import _


@process_definition(name='commentmanagement', id='commentmanagement')
class CommentManagement(ProcessDefinition, VisualisableElement):
    isUnique = True

    def __init__(self, **kwargs):
        super(CommentManagement, self).__init__(**kwargs)
        self.title = _('Comment management')
        self.description = _('Comment management')

    def _init_definition(self):
        self.defineNodes(
                start = StartEventDefinition(),
                pg = ParallelGatewayDefinition(),
                respond = ActivityDefinition(contexts=[Respond],
                                       description=_("Respond"),
                                       title=_("Respond"),
                                       groups=[]),
                eg = ExclusiveGatewayDefinition(),
                end = EndEventDefinition(),
        )
        self.defineTransitions(
                TransitionDefinition('start', 'pg'),
                TransitionDefinition('pg', 'respond'),
                TransitionDefinition('respond', 'eg'),
                TransitionDefinition('eg', 'end'),
        )

==> novaideo-1.1.tar.gz: novaideo-1.1/novaideo/content/processes/comment_management/definition.py <==
# Copyright (c) 2014 by Ecreall under licence AGPL terms
# avalaible on http://www.gnu.org/licenses/agpl.html

# licence: AGPL
# author: Amen Souissi
"""
This module represent the Comment management process definition
powered by the dace engine. This process is unique, which means that
this process is instantiated only once.
"""
from dace.processdefinition.processdef import ProcessDefinition
from dace.processdefinition.activitydef import ActivityDefinition
from dace.processdefinition.gatewaydef import (
    ExclusiveGatewayDefinition,
    ParallelGatewayDefinition)
from dace.processdefinition.transitiondef import TransitionDefinition
from dace.processdefinition.eventdef import (
    StartEventDefinition,
    EndEventDefinition)
from dace.objectofcollaboration.services.processdef_container import (
    process_definition)
from pontus.core import VisualisableElement

from .behaviors import (
    Respond,
    Edit,
    Remove,
    Pin,
    Unpin)
from novaideo import _


@process_definition(name='commentmanagement', id='commentmanagement')
class CommentManagement(ProcessDefinition, VisualisableElement):
    isUnique = True

    def __init__(self, **kwargs):
        super(CommentManagement, self).__init__(**kwargs)
        self.title = _('Comment management')
        self.description = _('Comment management')

    def _init_definition(self):
        self.defineNodes(
                start = StartEventDefinition(),
                pg = ParallelGatewayDefinition(),
                respond = ActivityDefinition(contexts=[Respond],
                                       description=_("Respond"),
                                       title=_("Respond"),
                                       groups=[]),
                edit = ActivityDefinition(contexts=[Edit],
                                       description=_("Edit"),
                                       title=_("Edit"),
                                       groups=[]),
                remove = ActivityDefinition(contexts=[Remove],
                                       description=_("Remove"),
                                       title=_("Remove"),
                                       groups=[]),
                pin = ActivityDefinition(contexts=[Pin],
                                       description=_("Pin"),
                                       title=_("Pin"),
                                       groups=[]),
                unpin = ActivityDefinition(contexts=[Unpin],
                                       description=_("Unpin"),
                                       title=_("Unpin"),
                                       groups=[]),
                eg = ExclusiveGatewayDefinition(),
                end = EndEventDefinition(),
        )
        self.defineTransitions(
                TransitionDefinition('start', 'pg'),
                TransitionDefinition('pg', 'respond'),
                TransitionDefinition('respond', 'eg'),
                TransitionDefinition('pg', 'edit'),
                TransitionDefinition('edit', 'eg'),
                TransitionDefinition('pg', 'remove'),
                TransitionDefinition('remove', 'eg'),
                TransitionDefinition('pg', 'pin'),
                TransitionDefinition('pin', 'eg'),
                TransitionDefinition('pg', 'unpin'),
                TransitionDefinition('unpin', 'eg'),
                TransitionDefinition('eg', 'end'),
        )
